/* opkg_configure.h - the opkg package management system

   Carl D. Worth

   Copyright (C) 2001 University of Southern California

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
   published by the Free Software Foundation; either version 2, or (at
   your option) any later version.

   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.
*/

#ifndef OPKG_CONFIGURE_H
#define OPKG_CONFIGURE_H

#ifdef __cplusplus
extern "C" {
#endif

#include "pkg.h"

int opkg_configure(pkg_t *pkg);

#ifdef __cplusplus
}
#endif

#endif /* OPKG_CONFIGURE_H */
